@@ -4,12 +4,12 @@ GCV <- function(object, ...) UseMethod("GCV")
 GCV.ibr <- function(object, ...) {
   r <- object$residuals
   n <- length(r)
-  stderr <- sqrt(sum(r^2)/(n-object$finaldf))
+  stderr <- sqrt(sum(r^2)/(n))
   return(log(stderr^2)-2*log(1-object$finaldf/n))
 }
 AICc.ibr <- function(object, ...) {
   r <- object$residuals
   n <- length(r)
-  stderr <- sqrt(sum(r^2)/(n-object$finaldf))
+  stderr <- sqrt(sum(r^2)/(n))
   return(log(stderr^2)+1+(2*(object$finaldf+1))/(n-object$finaldf-2))
 }
